Enum pcsc::Attribute
[−]
[src]
#[repr(C)]pub enum Attribute { VendorName, VendorIfdType, VendorIfdVersion, VendorIfdSerialNo, ChannelId, AsyncProtocolTypes, DefaultClk, MaxClk, DefaultDataRate, MaxDataRate, MaxIfsd, SyncProtocolTypes, PowerMgmtSupport, UserToCardAuthDevice, UserAuthInputDevice, Characteristics, CurrentProtocolType, CurrentClk, CurrentF, CurrentD, CurrentN, CurrentW, CurrentIfsc, CurrentIfsd, CurrentBwt, CurrentCwt, CurrentEbcEncoding, ExtendedBwt, IccPresence, IccInterfaceStatus, CurrentIoState, AtrString, IccTypePerAtr, EscReset, EscCancel, EscAuthrequest, Maxinput, DeviceUnit, DeviceInUse, DeviceFriendlyName, DeviceSystemName, SupressT1IfsRequest, }
Card reader attribute types.
Variants
VendorNameVendorIfdTypeVendorIfdVersionVendorIfdSerialNoChannelIdAsyncProtocolTypesDefaultClkMaxClkDefaultDataRateMaxDataRateMaxIfsdSyncProtocolTypesPowerMgmtSupportUserToCardAuthDeviceUserAuthInputDeviceCharacteristicsCurrentProtocolTypeCurrentClkCurrentFCurrentDCurrentNCurrentWCurrentIfscCurrentIfsdCurrentBwtCurrentCwtCurrentEbcEncodingExtendedBwtIccPresenceIccInterfaceStatusCurrentIoStateAtrStringIccTypePerAtrEscResetEscCancelEscAuthrequestMaxinputDeviceUnitDeviceInUseDeviceFriendlyNameDeviceSystemNameSupressT1IfsRequestTrait Implementations
impl Debug for Attribute[src]
impl Clone for Attribute[src]
fn clone(&self) -> Attribute
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl Copy for Attribute[src]
impl PartialEq for Attribute[src]
fn eq(&self, __arg_0: &Attribute) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Rhs) -> bool1.0.0
This method tests for !=.
impl Eq for Attribute[src]
impl Hash for Attribute[src]
fn hash<__H: Hasher>(&self, __arg_0: &mut __H)
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.