Struct pcsc::Card [] [src]

pub struct Card<'ctx> { /* fields omitted */ }

A connection to a smart card.

Methods

impl<'ctx> Card<'ctx>
[src]

Start a new exclusive transaction with the card.

Any further operations for the duration of the transaction should be performed through the returned Transaction.

This function wraps SCardBeginTransaction (pcsclite, MSDN).

Reconnect to the card.

This function wraps SCardReconnect (pcsclite, MSDN).

Disconnect from the card.

In case of error, ownership of the card is returned to the caller.

This function wraps SCardDisconnect (pcsclite, MSDN).

Note

Card implements Drop which automatically disconnects the card using Disposition::ResetCard; you only need to call this function if you want to handle errors or use a different disposition method.

Get current info on the card.

This function wraps SCardStatus (pcsclite, MSDN).

Get an attribute of the card or card reader.

buffer is a buffer that should be large enough for the attribute data.

Returns a slice into buffer containing the attribute data.

If the buffer is not large enough, Error::InsufficientBuffer is returned.

This function wraps SCardGetAttrib (pcsclite, MSDN).

Set an attribute of the card or card reader.

This function wraps SCardSetAttrib (pcsclite, MSDN).

Transmit an APDU command to the card.

receive_buffer is a buffer that should be large enough to hold the APDU response.

Returns a slice into receive_buffer containing the APDU response.

If receive_buffer is not large enough to hold the APDU response, Error::InsufficientBuffer is returned.

This function wraps SCardTransmit (pcsclite, MSDN).